@@ -11,8 +11,9 @@ ProtobufMessage = google.protobuf.message.Message
 
 
 import nibiru.common  # noqa
+import nibiru.msg  # noqa
 from nibiru.client import GrpcClient  # noqa
-from nibiru.common import Coin, Direction, PoolAsset, Side, TxConfig  # noqa
+from nibiru.common import Coin, Direction, PoolAsset, Side, TxConfig, TxType  # noqa
 from nibiru.network import Network  # noqa
 from nibiru.sdk import Sdk  # noqa
 from nibiru.transaction import Transaction  # noqa
